#[repr(u8)]pub enum Sstart {
VALUE00 = 0,
VALUE01 = 1,
VALUE10 = 2,
VALUE11 = 3,
}Variants
VALUE00 = 0
Start bit disabled for transmitter/receiver/match store, transmitter loads data on enable
VALUE01 = 1
Start bit disabled for transmitter/receiver/match store, transmitter loads data on first shift
VALUE10 = 2
Transmitter outputs start bit value 0 before loading data on first shift, receiver/match store sets error flag if start bit is not 0
VALUE11 = 3
Transmitter outputs start bit value 1 before loading data on first shift, receiver/match store sets error flag if start bit is not 1
Implementations