#[repr(u8)]pub enum Sstop {
VALUE00 = 0,
_RESERVED_1 = 1,
VALUE10 = 2,
VALUE11 = 3,
}Variants
VALUE00 = 0
Stop bit disabled for transmitter/receiver/match store
_RESERVED_1 = 1
VALUE10 = 2
Transmitter outputs stop bit value 0 on store, receiver/match store sets error flag if stop bit is not 0
VALUE11 = 3
Transmitter outputs stop bit value 1 on store, receiver/match store sets error flag if stop bit is not 1
Implementations