#[repr(u8)]pub enum Timout {
ONE = 0,
ZERO = 1,
ONE_TMRRESET = 2,
ZERO_TMRRESET = 3,
}Variants
ONE = 0
Timer output is logic one when enabled and is not affected by timer reset
ZERO = 1
Timer output is logic zero when enabled and is not affected by timer reset
ONE_TMRRESET = 2
Timer output is logic one when enabled and on timer reset
ZERO_TMRRESET = 3
Timer output is logic zero when enabled and on timer reset
Implementations